@@ -23,7 +23,7 @@ from defusedxml.ElementTree import fromstring
 
 _LOGGER = logging.getLogger(__name__)
 
-AsyncClient = httpx.AsyncClient
+AsyncClient = httpx.AsyncClient()
 
 SSDP_ADDR = "239.255.255.250"
 SSDP_PORT = 1900
@@ -92,7 +92,7 @@ async def async_identify_denonavr_receivers() -> List[Dict]:
 
     for url in urls:
         try:
-            async with AsyncClient() as client:
+            async with AsyncClient as client:
                 res = await client.get(url, timeout=5.0)
                 res.raise_for_status()
         except httpx.HTTPError:
